package com.vandyo.sentry.core.cases;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.vandyo.sentry.core.collectionMachine.CollectionMachine;
import com.vandyo.sentry.core.dto.ErrStatus;
import com.vandyo.sentry.core.dto.Res;
import com.vandyo.sentry.core.tools.Signature;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 获取车信息接口
 */
public class CarInfoDecorator extends CaseDecorator {

    private final static String carInfoUrl = "/car/my_car/info";

    public CarInfoDecorator(Case aCase) {
        super(aCase);
    }

    @Override
    public Res<Map<String, String>> check() {
        Res<Map<String,String>> oldRes = super.check();
        if (oldRes.getSuccess()) {
            Map<String, String> carMap = oldRes.getData();
            Res<Map<String,String>> newRes = new Res<>();
            newRes.setSId(oldRes.getSId());
            newRes.setUId(oldRes.getUId());

            if (Objects.isNull(carMap) || !carMap.containsKey("cid")){
                newRes.setStatus(ErrStatus.ErrUnexpected);
                newRes.setSuccess(false);
            }else {
                String cid = carMap.get("cid");
                Map<String,String> paramMap = new HashMap<>();
                paramMap.put("cid",cid);
                paramMap.put("uid",oldRes.getUId());

                HttpResponse response = HttpRequest.get(
                        Signature.host + carInfoUrl + "?"
                        + Signature.getUrlParamsByMap(Signature.sign(paramMap,oldRes.getSId()))
                ).execute();

                if (response.isOk()){
                    JSONObject jsonObject = JSONUtil.parseObj(response.body());
                    //todo 检测 返回值可用性
                    newRes.setData(carMap);
                    newRes.setSuccess(true);
                }else {
                    newRes.setKey(carInfoUrl);
                    newRes.setStatus(Signature.matchStatus(response.getStatus()));
                    newRes.setSuccess(false);
                }
            }
            CollectionMachine.post(newRes);
            return newRes;
        }else {
            oldRes.setIgnore(true);
            return oldRes;
        }
    }
}
